@@ -14,8 +14,8 @@ OC.L10N.register(
     "Week" : "Semana",
     "Month" : "Mes",
     "List" : "Lista",
-    "Download" : "Descargar",
     "Delete" : "Borrar",
+    "Download" : "Descargar",
     "Share link" : "Compartir enlace",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
@@ -27,22 +27,23 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "Show week numbers" : "Mostrar número de semana",
     "Settings & import" : "Configuraciones & importar",
+    "Location" : "Ubicación",
+    "Description" : "Descripción",
+    "Monday" : "Lunes",
+    "Save" : "Guardar",
+    "Update" : "Actualizar",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
     "Unknown" : "Desconocido",
     "All day" : "Todo el día",
+    "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
-    "Repeat" : "Repetir",
-    "Monday" : "Lunes",
-    "Summary" : "Resumen",
     "More" : "Más",
-    "Save" : "Guardar",
-    "Update" : "Actualizar",
+    "Global" : "Global",
     "Personal" : "Personal",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
-    "Reminders" : "Recordatorios",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
@@ -51,13 +52,10 @@ OC.L10N.register(
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
-    "Location" : "Ubicación",
-    "Description" : "Descripción",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Tentative" : "Tentativo",
     "Categories" : "Categorías",
-    "Mail" : "Correo",
-    "Global" : "Global"
+    "Mail" : "Correo"
 },
 "nplurals=2; plural=(n != 1);");
