@@ -11,39 +11,37 @@ OC.L10N.register(
     "Day" : "Dag",
     "Week" : "Veke",
     "Month" : "Månad",
-    "Download" : "Last ned",
     "Delete" : "Slett",
+    "Download" : "Last ned",
     "Share link" : "Del lenkje",
     "can edit" : "kan endra",
     "New calendar" : "Ny kalender",
     "Cancel" : "Avbryt",
     "Actions" : "Handlingar",
-    "Email" : "E-post",
-    "Unknown" : "Ukjend",
-    "never" : "aldri",
-    "after" : "etter",
-    "Repeat" : "Gjenta",
+    "Location" : "Stad",
+    "Description" : "Skildring",
     "Monday" : "Måndag",
-    "Summary" : "Oppsumering",
-    "More" : "Meir",
     "Save" : "Lagre",
     "Update" : "Oppdater",
+    "Email" : "E-post",
+    "Unknown" : "Ukjend",
+    "Repeat" : "Gjenta",
+    "never" : "aldri",
+    "after" : "etter",
+    "More" : "Meir",
+    "Global" : "Global",
     "Personal" : "Personleg",
     "Details" : "Detaljar",
     "Attendees" : "Deltakarar",
-    "Reminders" : "Påminningar",
     "Close" : "Lukk",
     "Daily" : "Kvar dag",
     "Weekly" : "Kvar veke",
     "When shared show full event" : "Når delt, vis heile hendinga",
     "When shared show only busy" : "Når delt, vis berre oppteken",
     "When shared hide this event" : "Når delt, gøym denne hendinga",
-    "Location" : "Stad",
-    "Description" : "Skildring",
     "Status" : "Status",
     "Confirmed" : "Stadfesta",
     "Tentative" : "Førebels",
-    "Mail" : "Post",
-    "Global" : "Global"
+    "Mail" : "Post"
 },
 "nplurals=2; plural=(n != 1);");
