@@ -19,6 +19,8 @@ OC.L10N.register(
     "Week" : "Aquesta setmana",
     "Month" : "Mes",
     "List" : "Tièra",
+    "Edit" : "Modificar",
+    "Delete" : "Suprimir",
     "Untitled calendar" : "Calendièr sens nom",
     "Edit name" : "Modificar lo nom",
     "Saving name …" : "Enregistrament del nom …",
@@ -26,7 +28,6 @@ OC.L10N.register(
     "Saving color …" : "Enregistrament de la color …",
     "Copy private link" : "Copiar lo ligam privat",
     "Download" : "Telecargar",
-    "Delete" : "Suprimir",
     "Share link" : "Partejar lo ligam",
     "Publish calendar" : "Publicar lo calendièr",
     "Copy public link" : "Copiar lo ligam public",
@@ -36,7 +37,6 @@ OC.L10N.register(
     "can edit" : "pòt modificar",
     "+ New calendar" : "+ Calendièr novèl",
     "New calendar" : "Calendièr novèl",
-    "Untitled event" : "Eveniment sens nom",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
@@ -50,6 +50,12 @@ OC.L10N.register(
     "Month view" : "Monstrar un mes",
     "Actions" : "Accions",
     "Show weekends" : "Monstrar las dimenjadas",
+    "Location" : "Emplaçament",
+    "Description" : "Descripcion",
+    "Monday" : "diluns",
+    "Save" : "Salvar",
+    "Update" : "Metre a jorn",
+    "Reminder" : "Recòrd",
     "Notification" : "Notificacion",
     "Email" : "Adreça corrièl",
     "Audio notification" : "Notificacion àudio",
@@ -64,10 +70,10 @@ OC.L10N.register(
     "_hour_::_hours_" : ["ora","oras"],
     "_day_::_days_" : ["jorn","jorns"],
     "_week_::_weeks_" : ["setmana","setmanas"],
-    "No reminders yet" : "Cap de rapèl pel moment",
     "Busy" : "Ocupat",
     "Unknown" : "Desconegut",
     "All day" : "Tota la jornada",
+    "Repeat" : "Repetir",
     "never" : "pas jamai",
     "after" : "aprèp",
     "_time_::_times_" : ["còp","còps"],
@@ -76,18 +82,17 @@ OC.L10N.register(
     "fourth" : "quatren",
     "fifth" : "cinquen",
     "last" : "darrièr",
-    "Repeat" : "Repetir",
     "_month_::_months_" : ["mes","mese"],
     "_year_::_years_" : ["annada","annadas"],
-    "Monday" : "diluns",
+    "Suggestions" : "Suggestions",
+    "Add resource" : "Apondre ressorsa",
     "More" : "Mai",
-    "Save" : "Salvar",
-    "Update" : "Metre a jorn",
-    "Please select a timezone:" : "Causissètz una zòna orària :",
     "Pick a time" : "Causir una ora",
     "Pick a date" : "Causir una data",
     "from {formattedDate}" : "a partir de {formattedDate}",
     "to {formattedDate}" : "cap a {formattedDate}",
+    "Type to search time zone" : "Picar per cercar un fus orari",
+    "Global" : "Global",
     "Personal" : "Personal",
     "[Today]" : "[Uèi]",
     "[Tomorrow]" : "[Deman]",
@@ -95,7 +100,6 @@ OC.L10N.register(
     "[Last] dddd" : "dddd [passat]",
     "Details" : "Detalhs",
     "Attendees" : "Convidats",
-    "Reminders" : "Rapèls",
     "Close" : "Tampar",
     "Download {name}" : "Telecargar {name}",
     "Anniversary" : "Anniversari",
@@ -115,10 +119,9 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
     "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
     "_%n time_::_%n times_" : ["%n còp","%n còps"],
+    "Untitled event" : "Eveniment sens nom",
     "Untitled task" : "Prètzfach sens nom",
-    "Location" : "Emplaçament",
     "Add a location" : "Apondre un lòc",
-    "Description" : "Descripcion",
     "Add a description" : "Apondre una descripcion",
     "Status" : "Estat",
     "Confirmed" : "Confirmat",
@@ -142,12 +145,13 @@ OC.L10N.register(
     "Dentist" : "Dentista",
     "Training" : "Entraïnament",
     "Sports" : "Espòrt",
+    "Written test" : "Test escrich",
+    "Oral test" : "Test oral",
     "Christmas" : "Nadal",
     "Conference" : "Conferéncia",
     "Pizza" : "Pizza",
     "Travelling" : "Viatge",
     "Party" : "Fèsta",
-    "Shopping" : "Crompas",
-    "Global" : "Global"
+    "Shopping" : "Crompas"
 },
 "nplurals=2; plural=(n > 1);");
