@@ -28,19 +28,18 @@ OC.L10N.register(
     "Filename" : "ගොනු නාමය",
     "Cancel" : "අවලංගු කරන්න",
     "Actions" : "ක්‍රියාමාර්ග",
+    "Location" : "ස්ථානය",
+    "Description" : "විස්තරය",
+    "Monday" : "සඳුදා",
+    "Save" : "සුරකින්න",
+    "Update" : "යාවත්කාල",
     "Email" : "විද්‍යුත් තැපෑල",
     "Busy" : "කාර්යබහුලයි",
     "Unknown" : "නොදන්නා",
-    "Monday" : "සඳුදා",
-    "Summary" : "සාරාංශය",
     "More" : "තව",
-    "Save" : "සුරකින්න",
-    "Update" : "යාවත්කාල",
     "Personal" : "පුද්ගලික",
     "Details" : "විස්තර",
     "Close" : "වසන්න",
-    "Anniversary" : "සංවත්සරය",
-    "Location" : "ස්ථානය",
-    "Description" : "විස්තරය"
+    "Anniversary" : "සංවත්සරය"
 },
 "nplurals=2; plural=(n != 1);");
