@@ -13,10 +13,10 @@ OC.L10N.register(
     "Week" : "Недеља",
     "Month" : "Месец",
     "List" : "Излистај",
+    "Delete" : "Обриши",
     "Edit name" : "Измени име",
     "Copy private link" : "Копирај приватну везу",
     "Download" : "Преузми",
-    "Delete" : "Обриши",
     "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
     "Calendar link copied to clipboard." : "Веза календара копирана у оставу.",
     "Calendar link could not be copied to clipboard." : "Веза календара није могла да се копира у оставу.",
@@ -27,7 +27,6 @@ OC.L10N.register(
     "can edit" : "може да мења",
     "Unshare with {displayName}" : "Уклони дељење са {displayName}",
     "New calendar" : "Нови календар",
-    "Untitled event" : "Неименовани догађај",
     "Filename" : "Име фајла",
     "Cancel" : "Одустани",
     "Automatic" : "Аутоматски",
@@ -36,37 +35,37 @@ OC.L10N.register(
     "Show week numbers" : "Прикажи број седмице",
     "Show keyboard shortcuts" : "Прикажи пречице тастатуре",
     "Settings & import" : "Поставке & увоз",
+    "Location" : "Локација",
+    "Description" : "Опис",
+    "Monday" : "Понедељак",
+    "Save" : "Сачувај",
+    "Update" : "Ажурирај",
     "Notification" : "Обавештење",
     "Email" : "Е-пошта",
     "Busy" : "Заузет",
     "Unknown" : "Непознато",
     "All day" : "Цео дан",
+    "Repeat" : "Понављај",
     "never" : "никада",
     "after" : "након",
-    "Repeat" : "Понављај",
-    "Monday" : "Понедељак",
-    "Summary" : "Сумарно",
     "More" : "Остало",
-    "Save" : "Сачувај",
-    "Update" : "Ажурирај",
+    "Global" : "Цео свет",
     "Personal" : "Лично",
     "[Today]" : "[Данас]",
     "[Tomorrow]" : "[Сутра]",
     "[Yesterday]" : "[Јуче]",
     "Details" : "Детаљи",
     "Attendees" : "Присутни",
-    "Reminders" : "Подсетници",
     "Close" : "Затвори",
     "Anniversary" : "Годишњица",
     "Week {number} of {year}" : "Недеља {number} у {year}",
     "Daily" : "дневно",
     "Weekly" : "недељно",
+    "Untitled event" : "Неименовани догађај",
     "Untitled task" : "Неименовани задатак",
     "When shared show full event" : "Прикажи цео догађај када је догађај дељен",
     "When shared show only busy" : "Прикажи само да сте заузети када је догађај дељен",
     "When shared hide this event" : "Сакриј догађај када је догађај дељен",
-    "Location" : "Локација",
-    "Description" : "Опис",
     "Status" : "Статус",
     "Confirmed" : "Потврђен",
     "Tentative" : "Условна потврда",
@@ -77,7 +76,6 @@ OC.L10N.register(
     "Cinema" : "Биоскоп",
     "Review" : "Претпреглед",
     "Mail" : "поштом",
-    "Dentist" : "Стоматолог",
-    "Global" : "Цео свет"
+    "Dentist" : "Стоматолог"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
